@@ -14,6 +14,7 @@ class Boards(Enum):
     STM32F411E_DISCO = 'STM32F411E-DISCO'
     STM32F469I_DISCO = 'STM32F469I-DISCO'
     STM32F769I_DISCO = 'STM32F769I-DISCO'
+    STM32H735G_DK = 'STM32H735G-DK'
     STM32H747I_DISCO = 'STM32H747I-DISCO'
 
 
@@ -23,6 +24,7 @@ _BOARD_TO_MCU = {
     Boards.STM32F411E_DISCO: Microcontrollers.STM32,
     Boards.STM32F469I_DISCO: Microcontrollers.STM32,
     Boards.STM32F769I_DISCO: Microcontrollers.STM32,
+    Boards.STM32H735G_DK: Microcontrollers.STM32,
     Boards.STM32H747I_DISCO: Microcontrollers.STM32,
 }
 
