@@ -61,6 +61,7 @@ class MessageCode(Enum):
 BOARDS = [
     Boards.STM32F469I_DISCO.value,
     Boards.STM32F769I_DISCO.value,
+    Boards.STM32H735G_DK.value,
     Boards.STM32H747I_DISCO.value,
     Boards.STM32F407G_DISCO.value,
     Boards.STM32F411E_DISCO.value,
@@ -73,6 +74,7 @@ AUDIO_DEBUG_RECORD_DURATION_SEC = {
     Boards.STM32H747I_DISCO.value: 3,
     Boards.STM32F407G_DISCO.value: 1,
     Boards.STM32F411E_DISCO.value: 1,
+    Boards.STM32H735G_DK.value: 3,
     Boards.IMXRT1050_EVKB.value: 3
 }
 AUDIO_DEBUG_FFT_WINDOW_SIZE = 512
@@ -293,7 +295,7 @@ class UploadFirmwareFrame(tk.Frame, PicoFrame):
         self._boards_tree_view = ttk.Treeview(
             self,
             cursor='hand2',
-            height=6,
+            height=7,
             show='tree')
         for i, x in enumerate(BOARDS):
             self._boards_tree_view.insert('', 'end', text=x)
